# coding: utf-8

"""
    Conversations Custom Channels

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictBool, StrictInt, StrictStr
from typing import List, Optional
from typing_extensions import Annotated
from hubspot.conversations.custom_channels.models.collection_response_with_total_public_channel_account_forward_paging import CollectionResponseWithTotalPublicChannelAccountForwardPaging
from hubspot.conversations.custom_channels.models.public_channel_account import PublicChannelAccount
from hubspot.conversations.custom_channels.models.public_channel_account_egg import PublicChannelAccountEgg
from hubspot.conversations.custom_channels.models.public_channel_account_update_request import PublicChannelAccountUpdateRequest

from hubspot.conversations.custom_channels.api_client import ApiClient, RequestSerialized
from hubspot.conversations.custom_channels.api_response import ApiResponse
from hubspot.conversations.custom_channels.rest import RESTResponseType


class ChannelAccountsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def get_conversations_v3_custom_channels_channel_id_channel_accounts(
        self,
        channel_id: StrictInt,
        delivery_identifier_type: Optional[List[StrictStr]] = None,
        delivery_identifier_value: Optional[List[StrictStr]] = None,
        after: Optional[StrictStr] = None,
        limit: Optional[StrictInt] = None,
        sort: Optional[List[StrictStr]] = None,
        default_page_length: Optional[StrictInt] = None,
        archived: Optional[StrictBool] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> CollectionResponseWithTotalPublicChannelAccountForwardPaging:
        """Query channel accounts


        :param channel_id:  (required)
        :type channel_id: int
        :param delivery_identifier_type: 
        :type delivery_identifier_type: List[str]
        :param delivery_identifier_value: 
        :type delivery_identifier_value: List[str]
        :param after: 
        :type after: str
        :param limit: 
        :type limit: int
        :param sort: 
        :type sort: List[str]
        :param default_page_length: 
        :type default_page_length: int
        :param archived: 
        :type archived: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_conversations_v3_custom_channels_channel_id_channel_accounts_serialize(
            channel_id=channel_id,
            delivery_identifier_type=delivery_identifier_type,
            delivery_identifier_value=delivery_identifier_value,
            after=after,
            limit=limit,
            sort=sort,
            default_page_length=default_page_length,
            archived=archived,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CollectionResponseWithTotalPublicChannelAccountForwardPaging",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_conversations_v3_custom_channels_channel_id_channel_accounts_with_http_info(
        self,
        channel_id: StrictInt,
        delivery_identifier_type: Optional[List[StrictStr]] = None,
        delivery_identifier_value: Optional[List[StrictStr]] = None,
        after: Optional[StrictStr] = None,
        limit: Optional[StrictInt] = None,
        sort: Optional[List[StrictStr]] = None,
        default_page_length: Optional[StrictInt] = None,
        archived: Optional[StrictBool] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[CollectionResponseWithTotalPublicChannelAccountForwardPaging]:
        """Query channel accounts


        :param channel_id:  (required)
        :type channel_id: int
        :param delivery_identifier_type: 
        :type delivery_identifier_type: List[str]
        :param delivery_identifier_value: 
        :type delivery_identifier_value: List[str]
        :param after: 
        :type after: str
        :param limit: 
        :type limit: int
        :param sort: 
        :type sort: List[str]
        :param default_page_length: 
        :type default_page_length: int
        :param archived: 
        :type archived: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_conversations_v3_custom_channels_channel_id_channel_accounts_serialize(
            channel_id=channel_id,
            delivery_identifier_type=delivery_identifier_type,
            delivery_identifier_value=delivery_identifier_value,
            after=after,
            limit=limit,
            sort=sort,
            default_page_length=default_page_length,
            archived=archived,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CollectionResponseWithTotalPublicChannelAccountForwardPaging",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_conversations_v3_custom_channels_channel_id_channel_accounts_without_preload_content(
        self,
        channel_id: StrictInt,
        delivery_identifier_type: Optional[List[StrictStr]] = None,
        delivery_identifier_value: Optional[List[StrictStr]] = None,
        after: Optional[StrictStr] = None,
        limit: Optional[StrictInt] = None,
        sort: Optional[List[StrictStr]] = None,
        default_page_length: Optional[StrictInt] = None,
        archived: Optional[StrictBool] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Query channel accounts


        :param channel_id:  (required)
        :type channel_id: int
        :param delivery_identifier_type: 
        :type delivery_identifier_type: List[str]
        :param delivery_identifier_value: 
        :type delivery_identifier_value: List[str]
        :param after: 
        :type after: str
        :param limit: 
        :type limit: int
        :param sort: 
        :type sort: List[str]
        :param default_page_length: 
        :type default_page_length: int
        :param archived: 
        :type archived: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_conversations_v3_custom_channels_channel_id_channel_accounts_serialize(
            channel_id=channel_id,
            delivery_identifier_type=delivery_identifier_type,
            delivery_identifier_value=delivery_identifier_value,
            after=after,
            limit=limit,
            sort=sort,
            default_page_length=default_page_length,
            archived=archived,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CollectionResponseWithTotalPublicChannelAccountForwardPaging",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_conversations_v3_custom_channels_channel_id_channel_accounts_serialize(
        self,
        channel_id,
        delivery_identifier_type,
        delivery_identifier_value,
        after,
        limit,
        sort,
        default_page_length,
        archived,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'deliveryIdentifierType': 'multi',
            'deliveryIdentifierValue': 'multi',
            'sort': 'multi',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if channel_id is not None:
            _path_params['channelId'] = channel_id
        # process the query parameters
        if delivery_identifier_type is not None:
            
            _query_params.append(('deliveryIdentifierType', delivery_identifier_type))
            
        if delivery_identifier_value is not None:
            
            _query_params.append(('deliveryIdentifierValue', delivery_identifier_value))
            
        if after is not None:
            
            _query_params.append(('after', after))
            
        if limit is not None:
            
            _query_params.append(('limit', limit))
            
        if sort is not None:
            
            _query_params.append(('sort', sort))
            
        if default_page_length is not None:
            
            _query_params.append(('defaultPageLength', default_page_length))
            
        if archived is not None:
            
            _query_params.append(('archived', archived))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json', 
                    '*/*'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'oauth2', 
            'private_apps'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/conversations/v3/custom-channels/{channelId}/channel-accounts',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_conversations_v3_custom_channels_channel_id_channel_accounts_channel_account_id(
        self,
        channel_id: StrictInt,
        channel_account_id: StrictInt,
        archived: Optional[StrictBool] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> PublicChannelAccount:
        """Get a channel account by id

        Retrieve a PublicChannelAccount that contains all the metadata about your channel account. This includes information like its channel, associated inbox id, and delivery identifier information.

        :param channel_id:  (required)
        :type channel_id: int
        :param channel_account_id:  (required)
        :type channel_account_id: int
        :param archived: 
        :type archived: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_conversations_v3_custom_channels_channel_id_channel_accounts_channel_account_id_serialize(
            channel_id=channel_id,
            channel_account_id=channel_account_id,
            archived=archived,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PublicChannelAccount",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_conversations_v3_custom_channels_channel_id_channel_accounts_channel_account_id_with_http_info(
        self,
        channel_id: StrictInt,
        channel_account_id: StrictInt,
        archived: Optional[StrictBool] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[PublicChannelAccount]:
        """Get a channel account by id

        Retrieve a PublicChannelAccount that contains all the metadata about your channel account. This includes information like its channel, associated inbox id, and delivery identifier information.

        :param channel_id:  (required)
        :type channel_id: int
        :param channel_account_id:  (required)
        :type channel_account_id: int
        :param archived: 
        :type archived: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_conversations_v3_custom_channels_channel_id_channel_accounts_channel_account_id_serialize(
            channel_id=channel_id,
            channel_account_id=channel_account_id,
            archived=archived,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PublicChannelAccount",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_conversations_v3_custom_channels_channel_id_channel_accounts_channel_account_id_without_preload_content(
        self,
        channel_id: StrictInt,
        channel_account_id: StrictInt,
        archived: Optional[StrictBool] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get a channel account by id

        Retrieve a PublicChannelAccount that contains all the metadata about your channel account. This includes information like its channel, associated inbox id, and delivery identifier information.

        :param channel_id:  (required)
        :type channel_id: int
        :param channel_account_id:  (required)
        :type channel_account_id: int
        :param archived: 
        :type archived: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_conversations_v3_custom_channels_channel_id_channel_accounts_channel_account_id_serialize(
            channel_id=channel_id,
            channel_account_id=channel_account_id,
            archived=archived,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PublicChannelAccount",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_conversations_v3_custom_channels_channel_id_channel_accounts_channel_account_id_serialize(
        self,
        channel_id,
        channel_account_id,
        archived,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if channel_id is not None:
            _path_params['channelId'] = channel_id
        if channel_account_id is not None:
            _path_params['channelAccountId'] = channel_account_id
        # process the query parameters
        if archived is not None:
            
            _query_params.append(('archived', archived))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json', 
                    '*/*'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'oauth2', 
            'private_apps'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/conversations/v3/custom-channels/{channelId}/channel-accounts/{channelAccountId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def patch_conversations_v3_custom_channels_channel_id_channel_accounts_channel_account_id(
        self,
        channel_id: Annotated[StrictInt, Field(description="The channel to update")],
        channel_account_id: Annotated[StrictInt, Field(description="The channel account to update")],
        public_channel_account_update_request: PublicChannelAccountUpdateRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> PublicChannelAccount:
        """Update a channel account

        This API is used to update the name of the channel account and it's isAuthorized status. Setting to isAuthorized flag to False disables the channel account.

        :param channel_id: The channel to update (required)
        :type channel_id: int
        :param channel_account_id: The channel account to update (required)
        :type channel_account_id: int
        :param public_channel_account_update_request: (required)
        :type public_channel_account_update_request: PublicChannelAccountUpdateRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._patch_conversations_v3_custom_channels_channel_id_channel_accounts_channel_account_id_serialize(
            channel_id=channel_id,
            channel_account_id=channel_account_id,
            public_channel_account_update_request=public_channel_account_update_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PublicChannelAccount",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def patch_conversations_v3_custom_channels_channel_id_channel_accounts_channel_account_id_with_http_info(
        self,
        channel_id: Annotated[StrictInt, Field(description="The channel to update")],
        channel_account_id: Annotated[StrictInt, Field(description="The channel account to update")],
        public_channel_account_update_request: PublicChannelAccountUpdateRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[PublicChannelAccount]:
        """Update a channel account

        This API is used to update the name of the channel account and it's isAuthorized status. Setting to isAuthorized flag to False disables the channel account.

        :param channel_id: The channel to update (required)
        :type channel_id: int
        :param channel_account_id: The channel account to update (required)
        :type channel_account_id: int
        :param public_channel_account_update_request: (required)
        :type public_channel_account_update_request: PublicChannelAccountUpdateRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._patch_conversations_v3_custom_channels_channel_id_channel_accounts_channel_account_id_serialize(
            channel_id=channel_id,
            channel_account_id=channel_account_id,
            public_channel_account_update_request=public_channel_account_update_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PublicChannelAccount",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def patch_conversations_v3_custom_channels_channel_id_channel_accounts_channel_account_id_without_preload_content(
        self,
        channel_id: Annotated[StrictInt, Field(description="The channel to update")],
        channel_account_id: Annotated[StrictInt, Field(description="The channel account to update")],
        public_channel_account_update_request: PublicChannelAccountUpdateRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Update a channel account

        This API is used to update the name of the channel account and it's isAuthorized status. Setting to isAuthorized flag to False disables the channel account.

        :param channel_id: The channel to update (required)
        :type channel_id: int
        :param channel_account_id: The channel account to update (required)
        :type channel_account_id: int
        :param public_channel_account_update_request: (required)
        :type public_channel_account_update_request: PublicChannelAccountUpdateRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._patch_conversations_v3_custom_channels_channel_id_channel_accounts_channel_account_id_serialize(
            channel_id=channel_id,
            channel_account_id=channel_account_id,
            public_channel_account_update_request=public_channel_account_update_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PublicChannelAccount",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _patch_conversations_v3_custom_channels_channel_id_channel_accounts_channel_account_id_serialize(
        self,
        channel_id,
        channel_account_id,
        public_channel_account_update_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if channel_id is not None:
            _path_params['channelId'] = channel_id
        if channel_account_id is not None:
            _path_params['channelAccountId'] = channel_account_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if public_channel_account_update_request is not None:
            _body_params = public_channel_account_update_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json', 
                    '*/*'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'oauth2', 
            'private_apps'
        ]

        return self.api_client.param_serialize(
            method='PATCH',
            resource_path='/conversations/v3/custom-channels/{channelId}/channel-accounts/{channelAccountId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def post_conversations_v3_custom_channels_channel_id_channel_accounts(
        self,
        channel_id: StrictInt,
        public_channel_account_egg: PublicChannelAccountEgg,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> PublicChannelAccount:
        """Create a channel account

        This API allows you to create one or more accounts that all talk over a single channel but using different delivery identifiers.

        :param channel_id:  (required)
        :type channel_id: int
        :param public_channel_account_egg: (required)
        :type public_channel_account_egg: PublicChannelAccountEgg
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._post_conversations_v3_custom_channels_channel_id_channel_accounts_serialize(
            channel_id=channel_id,
            public_channel_account_egg=public_channel_account_egg,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "PublicChannelAccount",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def post_conversations_v3_custom_channels_channel_id_channel_accounts_with_http_info(
        self,
        channel_id: StrictInt,
        public_channel_account_egg: PublicChannelAccountEgg,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[PublicChannelAccount]:
        """Create a channel account

        This API allows you to create one or more accounts that all talk over a single channel but using different delivery identifiers.

        :param channel_id:  (required)
        :type channel_id: int
        :param public_channel_account_egg: (required)
        :type public_channel_account_egg: PublicChannelAccountEgg
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._post_conversations_v3_custom_channels_channel_id_channel_accounts_serialize(
            channel_id=channel_id,
            public_channel_account_egg=public_channel_account_egg,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "PublicChannelAccount",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def post_conversations_v3_custom_channels_channel_id_channel_accounts_without_preload_content(
        self,
        channel_id: StrictInt,
        public_channel_account_egg: PublicChannelAccountEgg,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Create a channel account

        This API allows you to create one or more accounts that all talk over a single channel but using different delivery identifiers.

        :param channel_id:  (required)
        :type channel_id: int
        :param public_channel_account_egg: (required)
        :type public_channel_account_egg: PublicChannelAccountEgg
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._post_conversations_v3_custom_channels_channel_id_channel_accounts_serialize(
            channel_id=channel_id,
            public_channel_account_egg=public_channel_account_egg,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "PublicChannelAccount",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _post_conversations_v3_custom_channels_channel_id_channel_accounts_serialize(
        self,
        channel_id,
        public_channel_account_egg,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if channel_id is not None:
            _path_params['channelId'] = channel_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if public_channel_account_egg is not None:
            _body_params = public_channel_account_egg


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json', 
                    '*/*'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'oauth2', 
            'private_apps'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/conversations/v3/custom-channels/{channelId}/channel-accounts',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

# flake8: noqa
"""
    Webhooks Webhooks

    Provides a way for apps to subscribe to certain change events in HubSpot. Once configured, apps will receive event payloads containing details about the changes at a specified target URL. There can only be one target URL for receiving event notifications per app.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from hubspot.webhooks.models.batch_input_subscription_batch_update_request import BatchInputSubscriptionBatchUpdateRequest
from hubspot.webhooks.models.batch_response_subscription_response import BatchResponseSubscriptionResponse
from hubspot.webhooks.models.batch_response_subscription_response_with_errors import BatchResponseSubscriptionResponseWithErrors
from hubspot.webhooks.models.error import Error
from hubspot.webhooks.models.error_detail import ErrorDetail
from hubspot.webhooks.models.settings_change_request import SettingsChangeRequest
from hubspot.webhooks.models.settings_response import SettingsResponse
from hubspot.webhooks.models.standard_error import StandardError
from hubspot.webhooks.models.subscription_batch_update_request import SubscriptionBatchUpdateRequest
from hubspot.webhooks.models.subscription_create_request import SubscriptionCreateRequest
from hubspot.webhooks.models.subscription_list_response import SubscriptionListResponse
from hubspot.webhooks.models.subscription_patch_request import SubscriptionPatchRequest
from hubspot.webhooks.models.subscription_response import SubscriptionResponse
from hubspot.webhooks.models.throttling_settings import ThrottlingSettings



# coding: utf-8

# flake8: noqa
"""
    CMS Domains

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from hubspot.cms.domains.models.collection_response_with_total_domain_forward_paging import CollectionResponseWithTotalDomainForwardPaging
from hubspot.cms.domains.models.domain import Domain
from hubspot.cms.domains.models.error import Error
from hubspot.cms.domains.models.error_detail import ErrorDetail
from hubspot.cms.domains.models.forward_paging import ForwardPaging
from hubspot.cms.domains.models.next_page import NextPage



# coding: utf-8

"""
    Schemas

    The CRM uses schemas to define how custom objects should store and represent information in the HubSpot CRM. Schemas define details about an object's type, properties, and associations. The schema can be uniquely identified by its **object type ID**.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.schemas.configuration import Configuration


class AssociationDefinition(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"created_at": "datetime", "from_object_type_id": "str", "name": "str", "id": "str", "to_object_type_id": "str", "updated_at": "datetime"}

    attribute_map = {"created_at": "createdAt", "from_object_type_id": "fromObjectTypeId", "name": "name", "id": "id", "to_object_type_id": "toObjectTypeId", "updated_at": "updatedAt"}

    def __init__(self, created_at=None, from_object_type_id=None, name=None, id=None, to_object_type_id=None, updated_at=None, local_vars_configuration=None):  # noqa: E501
        """AssociationDefinition - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._created_at = None
        self._from_object_type_id = None
        self._name = None
        self._id = None
        self._to_object_type_id = None
        self._updated_at = None
        self.discriminator = None

        if created_at is not None:
            self.created_at = created_at
        self.from_object_type_id = from_object_type_id
        if name is not None:
            self.name = name
        self.id = id
        self.to_object_type_id = to_object_type_id
        if updated_at is not None:
            self.updated_at = updated_at

    @property
    def created_at(self):
        """Gets the created_at of this AssociationDefinition.  # noqa: E501

        When the association was defined.  # noqa: E501

        :return: The created_at of this AssociationDefinition.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this AssociationDefinition.

        When the association was defined.  # noqa: E501

        :param created_at: The created_at of this AssociationDefinition.  # noqa: E501
        :type created_at: datetime
        """

        self._created_at = created_at

    @property
    def from_object_type_id(self):
        """Gets the from_object_type_id of this AssociationDefinition.  # noqa: E501

        ID of the primary object type to link from.  # noqa: E501

        :return: The from_object_type_id of this AssociationDefinition.  # noqa: E501
        :rtype: str
        """
        return self._from_object_type_id

    @from_object_type_id.setter
    def from_object_type_id(self, from_object_type_id):
        """Sets the from_object_type_id of this AssociationDefinition.

        ID of the primary object type to link from.  # noqa: E501

        :param from_object_type_id: The from_object_type_id of this AssociationDefinition.  # noqa: E501
        :type from_object_type_id: str
        """
        if self.local_vars_configuration.client_side_validation and from_object_type_id is None:  # noqa: E501
            raise ValueError("Invalid value for `from_object_type_id`, must not be `None`")  # noqa: E501

        self._from_object_type_id = from_object_type_id

    @property
    def name(self):
        """Gets the name of this AssociationDefinition.  # noqa: E501

        A unique name for this association.  # noqa: E501

        :return: The name of this AssociationDefinition.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AssociationDefinition.

        A unique name for this association.  # noqa: E501

        :param name: The name of this AssociationDefinition.  # noqa: E501
        :type name: str
        """

        self._name = name

    @property
    def id(self):
        """Gets the id of this AssociationDefinition.  # noqa: E501

        A unique ID for this association.  # noqa: E501

        :return: The id of this AssociationDefinition.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this AssociationDefinition.

        A unique ID for this association.  # noqa: E501

        :param id: The id of this AssociationDefinition.  # noqa: E501
        :type id: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def to_object_type_id(self):
        """Gets the to_object_type_id of this AssociationDefinition.  # noqa: E501

        ID of the target object type to link to.  # noqa: E501

        :return: The to_object_type_id of this AssociationDefinition.  # noqa: E501
        :rtype: str
        """
        return self._to_object_type_id

    @to_object_type_id.setter
    def to_object_type_id(self, to_object_type_id):
        """Sets the to_object_type_id of this AssociationDefinition.

        ID of the target object type to link to.  # noqa: E501

        :param to_object_type_id: The to_object_type_id of this AssociationDefinition.  # noqa: E501
        :type to_object_type_id: str
        """
        if self.local_vars_configuration.client_side_validation and to_object_type_id is None:  # noqa: E501
            raise ValueError("Invalid value for `to_object_type_id`, must not be `None`")  # noqa: E501

        self._to_object_type_id = to_object_type_id

    @property
    def updated_at(self):
        """Gets the updated_at of this AssociationDefinition.  # noqa: E501

        When the association was last updated.  # noqa: E501

        :return: The updated_at of this AssociationDefinition.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this AssociationDefinition.

        When the association was last updated.  # noqa: E501

        :param updated_at: The updated_at of this AssociationDefinition.  # noqa: E501
        :type updated_at: datetime
        """

        self._updated_at = updated_at

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AssociationDefinition):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AssociationDefinition):
            return True

        return self.to_dict() != other.to_dict()



import hubspot.files as api_client
from ..discovery_base import DiscoveryBase


class Discovery(DiscoveryBase):
    @property
    def files_api(self) -> api_client.FilesApi:
        return self._configure_api_client(api_client, "FilesApi")

    @property
    def folders_api(self) -> api_client.FoldersApi:
        return self._configure_api_client(api_client, "FoldersApi")



# coding: utf-8

"""
    Marketing Emails

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.marketing.emails.configuration import Configuration


class PublicWebversionDetails(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "domain": "str",
        "redirect_to_page_id": "str",
        "is_page_redirected": "bool",
        "redirect_to_url": "str",
        "title": "str",
        "meta_description": "str",
        "page_expiry_enabled": "bool",
        "slug": "str",
        "url": "str",
        "expires_at": "datetime",
    }

    attribute_map = {
        "domain": "domain",
        "redirect_to_page_id": "redirectToPageId",
        "is_page_redirected": "isPageRedirected",
        "redirect_to_url": "redirectToUrl",
        "title": "title",
        "meta_description": "metaDescription",
        "page_expiry_enabled": "pageExpiryEnabled",
        "slug": "slug",
        "url": "url",
        "expires_at": "expiresAt",
    }

    def __init__(
        self,
        domain=None,
        redirect_to_page_id=None,
        is_page_redirected=None,
        redirect_to_url=None,
        title=None,
        meta_description=None,
        page_expiry_enabled=None,
        slug=None,
        url=None,
        expires_at=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """PublicWebversionDetails - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._domain = None
        self._redirect_to_page_id = None
        self._is_page_redirected = None
        self._redirect_to_url = None
        self._title = None
        self._meta_description = None
        self._page_expiry_enabled = None
        self._slug = None
        self._url = None
        self._expires_at = None
        self.discriminator = None

        if domain is not None:
            self.domain = domain
        if redirect_to_page_id is not None:
            self.redirect_to_page_id = redirect_to_page_id
        if is_page_redirected is not None:
            self.is_page_redirected = is_page_redirected
        if redirect_to_url is not None:
            self.redirect_to_url = redirect_to_url
        if title is not None:
            self.title = title
        if meta_description is not None:
            self.meta_description = meta_description
        if page_expiry_enabled is not None:
            self.page_expiry_enabled = page_expiry_enabled
        if slug is not None:
            self.slug = slug
        if url is not None:
            self.url = url
        if expires_at is not None:
            self.expires_at = expires_at

    @property
    def domain(self):
        """Gets the domain of this PublicWebversionDetails.  # noqa: E501

          # noqa: E501

        :return: The domain of this PublicWebversionDetails.  # noqa: E501
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this PublicWebversionDetails.

          # noqa: E501

        :param domain: The domain of this PublicWebversionDetails.  # noqa: E501
        :type domain: str
        """

        self._domain = domain

    @property
    def redirect_to_page_id(self):
        """Gets the redirect_to_page_id of this PublicWebversionDetails.  # noqa: E501

          # noqa: E501

        :return: The redirect_to_page_id of this PublicWebversionDetails.  # noqa: E501
        :rtype: str
        """
        return self._redirect_to_page_id

    @redirect_to_page_id.setter
    def redirect_to_page_id(self, redirect_to_page_id):
        """Sets the redirect_to_page_id of this PublicWebversionDetails.

          # noqa: E501

        :param redirect_to_page_id: The redirect_to_page_id of this PublicWebversionDetails.  # noqa: E501
        :type redirect_to_page_id: str
        """

        self._redirect_to_page_id = redirect_to_page_id

    @property
    def is_page_redirected(self):
        """Gets the is_page_redirected of this PublicWebversionDetails.  # noqa: E501


        :return: The is_page_redirected of this PublicWebversionDetails.  # noqa: E501
        :rtype: bool
        """
        return self._is_page_redirected

    @is_page_redirected.setter
    def is_page_redirected(self, is_page_redirected):
        """Sets the is_page_redirected of this PublicWebversionDetails.


        :param is_page_redirected: The is_page_redirected of this PublicWebversionDetails.  # noqa: E501
        :type is_page_redirected: bool
        """

        self._is_page_redirected = is_page_redirected

    @property
    def redirect_to_url(self):
        """Gets the redirect_to_url of this PublicWebversionDetails.  # noqa: E501

          # noqa: E501

        :return: The redirect_to_url of this PublicWebversionDetails.  # noqa: E501
        :rtype: str
        """
        return self._redirect_to_url

    @redirect_to_url.setter
    def redirect_to_url(self, redirect_to_url):
        """Sets the redirect_to_url of this PublicWebversionDetails.

          # noqa: E501

        :param redirect_to_url: The redirect_to_url of this PublicWebversionDetails.  # noqa: E501
        :type redirect_to_url: str
        """

        self._redirect_to_url = redirect_to_url

    @property
    def title(self):
        """Gets the title of this PublicWebversionDetails.  # noqa: E501

          # noqa: E501

        :return: The title of this PublicWebversionDetails.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this PublicWebversionDetails.

          # noqa: E501

        :param title: The title of this PublicWebversionDetails.  # noqa: E501
        :type title: str
        """

        self._title = title

    @property
    def meta_description(self):
        """Gets the meta_description of this PublicWebversionDetails.  # noqa: E501

          # noqa: E501

        :return: The meta_description of this PublicWebversionDetails.  # noqa: E501
        :rtype: str
        """
        return self._meta_description

    @meta_description.setter
    def meta_description(self, meta_description):
        """Sets the meta_description of this PublicWebversionDetails.

          # noqa: E501

        :param meta_description: The meta_description of this PublicWebversionDetails.  # noqa: E501
        :type meta_description: str
        """

        self._meta_description = meta_description

    @property
    def page_expiry_enabled(self):
        """Gets the page_expiry_enabled of this PublicWebversionDetails.  # noqa: E501


        :return: The page_expiry_enabled of this PublicWebversionDetails.  # noqa: E501
        :rtype: bool
        """
        return self._page_expiry_enabled

    @page_expiry_enabled.setter
    def page_expiry_enabled(self, page_expiry_enabled):
        """Sets the page_expiry_enabled of this PublicWebversionDetails.


        :param page_expiry_enabled: The page_expiry_enabled of this PublicWebversionDetails.  # noqa: E501
        :type page_expiry_enabled: bool
        """

        self._page_expiry_enabled = page_expiry_enabled

    @property
    def slug(self):
        """Gets the slug of this PublicWebversionDetails.  # noqa: E501

          # noqa: E501

        :return: The slug of this PublicWebversionDetails.  # noqa: E501
        :rtype: str
        """
        return self._slug

    @slug.setter
    def slug(self, slug):
        """Sets the slug of this PublicWebversionDetails.

          # noqa: E501

        :param slug: The slug of this PublicWebversionDetails.  # noqa: E501
        :type slug: str
        """

        self._slug = slug

    @property
    def url(self):
        """Gets the url of this PublicWebversionDetails.  # noqa: E501


        :return: The url of this PublicWebversionDetails.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this PublicWebversionDetails.


        :param url: The url of this PublicWebversionDetails.  # noqa: E501
        :type url: str
        """

        self._url = url

    @property
    def expires_at(self):
        """Gets the expires_at of this PublicWebversionDetails.  # noqa: E501

          # noqa: E501

        :return: The expires_at of this PublicWebversionDetails.  # noqa: E501
        :rtype: datetime
        """
        return self._expires_at

    @expires_at.setter
    def expires_at(self, expires_at):
        """Sets the expires_at of this PublicWebversionDetails.

          # noqa: E501

        :param expires_at: The expires_at of this PublicWebversionDetails.  # noqa: E501
        :type expires_at: datetime
        """

        self._expires_at = expires_at

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicWebversionDetails):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PublicWebversionDetails):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Timeline

    This feature allows an app to create and configure custom events that can show up in the timelines of certain CRM objects like contacts, companies, tickets, or deals. You'll find multiple use cases for this API in the sections below.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.timeline.configuration import Configuration


class TimelineEventIFrame(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"link_label": "str", "header_label": "str", "width": "int", "url": "str", "height": "int"}

    attribute_map = {"link_label": "linkLabel", "header_label": "headerLabel", "width": "width", "url": "url", "height": "height"}

    def __init__(self, link_label=None, header_label=None, width=None, url=None, height=None, local_vars_configuration=None):  # noqa: E501
        """TimelineEventIFrame - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._link_label = None
        self._header_label = None
        self._width = None
        self._url = None
        self._height = None
        self.discriminator = None

        self.link_label = link_label
        self.header_label = header_label
        self.width = width
        self.url = url
        self.height = height

    @property
    def link_label(self):
        """Gets the link_label of this TimelineEventIFrame.  # noqa: E501

        The text displaying the link that will display the iframe.  # noqa: E501

        :return: The link_label of this TimelineEventIFrame.  # noqa: E501
        :rtype: str
        """
        return self._link_label

    @link_label.setter
    def link_label(self, link_label):
        """Sets the link_label of this TimelineEventIFrame.

        The text displaying the link that will display the iframe.  # noqa: E501

        :param link_label: The link_label of this TimelineEventIFrame.  # noqa: E501
        :type link_label: str
        """
        if self.local_vars_configuration.client_side_validation and link_label is None:  # noqa: E501
            raise ValueError("Invalid value for `link_label`, must not be `None`")  # noqa: E501

        self._link_label = link_label

    @property
    def header_label(self):
        """Gets the header_label of this TimelineEventIFrame.  # noqa: E501

        The label of the modal window that displays the iframe contents.  # noqa: E501

        :return: The header_label of this TimelineEventIFrame.  # noqa: E501
        :rtype: str
        """
        return self._header_label

    @header_label.setter
    def header_label(self, header_label):
        """Sets the header_label of this TimelineEventIFrame.

        The label of the modal window that displays the iframe contents.  # noqa: E501

        :param header_label: The header_label of this TimelineEventIFrame.  # noqa: E501
        :type header_label: str
        """
        if self.local_vars_configuration.client_side_validation and header_label is None:  # noqa: E501
            raise ValueError("Invalid value for `header_label`, must not be `None`")  # noqa: E501

        self._header_label = header_label

    @property
    def width(self):
        """Gets the width of this TimelineEventIFrame.  # noqa: E501

        The width of the modal window in pixels.  # noqa: E501

        :return: The width of this TimelineEventIFrame.  # noqa: E501
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this TimelineEventIFrame.

        The width of the modal window in pixels.  # noqa: E501

        :param width: The width of this TimelineEventIFrame.  # noqa: E501
        :type width: int
        """
        if self.local_vars_configuration.client_side_validation and width is None:  # noqa: E501
            raise ValueError("Invalid value for `width`, must not be `None`")  # noqa: E501

        self._width = width

    @property
    def url(self):
        """Gets the url of this TimelineEventIFrame.  # noqa: E501

        The URI of the iframe contents.  # noqa: E501

        :return: The url of this TimelineEventIFrame.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this TimelineEventIFrame.

        The URI of the iframe contents.  # noqa: E501

        :param url: The url of this TimelineEventIFrame.  # noqa: E501
        :type url: str
        """
        if self.local_vars_configuration.client_side_validation and url is None:  # noqa: E501
            raise ValueError("Invalid value for `url`, must not be `None`")  # noqa: E501

        self._url = url

    @property
    def height(self):
        """Gets the height of this TimelineEventIFrame.  # noqa: E501

        The height of the modal window in pixels.  # noqa: E501

        :return: The height of this TimelineEventIFrame.  # noqa: E501
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this TimelineEventIFrame.

        The height of the modal window in pixels.  # noqa: E501

        :param height: The height of this TimelineEventIFrame.  # noqa: E501
        :type height: int
        """
        if self.local_vars_configuration.client_side_validation and height is None:  # noqa: E501
            raise ValueError("Invalid value for `height`, must not be `None`")  # noqa: E501

        self._height = height

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TimelineEventIFrame):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TimelineEventIFrame):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Hubdb

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.cms.hubdb.configuration import Configuration


class HubDbTableV3(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "dynamic_meta_tags": "dict[str, int]",
        "updated_by": "SimpleUser",
        "allow_public_api_access": "bool",
        "use_for_pages": "bool",
        "published_at": "datetime",
        "columns": "list[Column]",
        "label": "str",
        "published": "bool",
        "column_count": "int",
        "allow_child_tables": "bool",
        "created_at": "datetime",
        "deleted": "bool",
        "created_by": "SimpleUser",
        "name": "str",
        "enable_child_table_pages": "bool",
        "id": "str",
        "row_count": "int",
        "is_ordered_manually": "bool",
        "updated_at": "datetime",
    }

    attribute_map = {
        "dynamic_meta_tags": "dynamicMetaTags",
        "updated_by": "updatedBy",
        "allow_public_api_access": "allowPublicApiAccess",
        "use_for_pages": "useForPages",
        "published_at": "publishedAt",
        "columns": "columns",
        "label": "label",
        "published": "published",
        "column_count": "columnCount",
        "allow_child_tables": "allowChildTables",
        "created_at": "createdAt",
        "deleted": "deleted",
        "created_by": "createdBy",
        "name": "name",
        "enable_child_table_pages": "enableChildTablePages",
        "id": "id",
        "row_count": "rowCount",
        "is_ordered_manually": "isOrderedManually",
        "updated_at": "updatedAt",
    }

    def __init__(
        self,
        dynamic_meta_tags=None,
        updated_by=None,
        allow_public_api_access=None,
        use_for_pages=None,
        published_at=None,
        columns=None,
        label=None,
        published=None,
        column_count=None,
        allow_child_tables=None,
        created_at=None,
        deleted=None,
        created_by=None,
        name=None,
        enable_child_table_pages=None,
        id=None,
        row_count=None,
        is_ordered_manually=None,
        updated_at=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """HubDbTableV3 - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._dynamic_meta_tags = None
        self._updated_by = None
        self._allow_public_api_access = None
        self._use_for_pages = None
        self._published_at = None
        self._columns = None
        self._label = None
        self._published = None
        self._column_count = None
        self._allow_child_tables = None
        self._created_at = None
        self._deleted = None
        self._created_by = None
        self._name = None
        self._enable_child_table_pages = None
        self._id = None
        self._row_count = None
        self._is_ordered_manually = None
        self._updated_at = None
        self.discriminator = None

        if dynamic_meta_tags is not None:
            self.dynamic_meta_tags = dynamic_meta_tags
        if updated_by is not None:
            self.updated_by = updated_by
        if allow_public_api_access is not None:
            self.allow_public_api_access = allow_public_api_access
        if use_for_pages is not None:
            self.use_for_pages = use_for_pages
        if published_at is not None:
            self.published_at = published_at
        if columns is not None:
            self.columns = columns
        self.label = label
        if published is not None:
            self.published = published
        if column_count is not None:
            self.column_count = column_count
        if allow_child_tables is not None:
            self.allow_child_tables = allow_child_tables
        if created_at is not None:
            self.created_at = created_at
        if deleted is not None:
            self.deleted = deleted
        if created_by is not None:
            self.created_by = created_by
        self.name = name
        if enable_child_table_pages is not None:
            self.enable_child_table_pages = enable_child_table_pages
        if id is not None:
            self.id = id
        if row_count is not None:
            self.row_count = row_count
        if is_ordered_manually is not None:
            self.is_ordered_manually = is_ordered_manually
        if updated_at is not None:
            self.updated_at = updated_at

    @property
    def dynamic_meta_tags(self):
        """Gets the dynamic_meta_tags of this HubDbTableV3.  # noqa: E501

        Specifies the key value pairs of the [metadata fields](https://developers.hubspot.com/docs/cms/guides/dynamic-pages/hubdb#dynamic-pages) with the associated column IDs.  # noqa: E501

        :return: The dynamic_meta_tags of this HubDbTableV3.  # noqa: E501
        :rtype: dict[str, int]
        """
        return self._dynamic_meta_tags

    @dynamic_meta_tags.setter
    def dynamic_meta_tags(self, dynamic_meta_tags):
        """Sets the dynamic_meta_tags of this HubDbTableV3.

        Specifies the key value pairs of the [metadata fields](https://developers.hubspot.com/docs/cms/guides/dynamic-pages/hubdb#dynamic-pages) with the associated column IDs.  # noqa: E501

        :param dynamic_meta_tags: The dynamic_meta_tags of this HubDbTableV3.  # noqa: E501
        :type dynamic_meta_tags: dict[str, int]
        """

        self._dynamic_meta_tags = dynamic_meta_tags

    @property
    def updated_by(self):
        """Gets the updated_by of this HubDbTableV3.  # noqa: E501


        :return: The updated_by of this HubDbTableV3.  # noqa: E501
        :rtype: SimpleUser
        """
        return self._updated_by

    @updated_by.setter
    def updated_by(self, updated_by):
        """Sets the updated_by of this HubDbTableV3.


        :param updated_by: The updated_by of this HubDbTableV3.  # noqa: E501
        :type updated_by: SimpleUser
        """

        self._updated_by = updated_by

    @property
    def allow_public_api_access(self):
        """Gets the allow_public_api_access of this HubDbTableV3.  # noqa: E501

        Specifies whether the table can be read by public without authorization  # noqa: E501

        :return: The allow_public_api_access of this HubDbTableV3.  # noqa: E501
        :rtype: bool
        """
        return self._allow_public_api_access

    @allow_public_api_access.setter
    def allow_public_api_access(self, allow_public_api_access):
        """Sets the allow_public_api_access of this HubDbTableV3.

        Specifies whether the table can be read by public without authorization  # noqa: E501

        :param allow_public_api_access: The allow_public_api_access of this HubDbTableV3.  # noqa: E501
        :type allow_public_api_access: bool
        """

        self._allow_public_api_access = allow_public_api_access

    @property
    def use_for_pages(self):
        """Gets the use_for_pages of this HubDbTableV3.  # noqa: E501

        Specifies whether the table can be used for creation of dynamic pages  # noqa: E501

        :return: The use_for_pages of this HubDbTableV3.  # noqa: E501
        :rtype: bool
        """
        return self._use_for_pages

    @use_for_pages.setter
    def use_for_pages(self, use_for_pages):
        """Sets the use_for_pages of this HubDbTableV3.

        Specifies whether the table can be used for creation of dynamic pages  # noqa: E501

        :param use_for_pages: The use_for_pages of this HubDbTableV3.  # noqa: E501
        :type use_for_pages: bool
        """

        self._use_for_pages = use_for_pages

    @property
    def published_at(self):
        """Gets the published_at of this HubDbTableV3.  # noqa: E501

        Timestamp at which the table is published recently  # noqa: E501

        :return: The published_at of this HubDbTableV3.  # noqa: E501
        :rtype: datetime
        """
        return self._published_at

    @published_at.setter
    def published_at(self, published_at):
        """Sets the published_at of this HubDbTableV3.

        Timestamp at which the table is published recently  # noqa: E501

        :param published_at: The published_at of this HubDbTableV3.  # noqa: E501
        :type published_at: datetime
        """

        self._published_at = published_at

    @property
    def columns(self):
        """Gets the columns of this HubDbTableV3.  # noqa: E501

        List of columns in the table  # noqa: E501

        :return: The columns of this HubDbTableV3.  # noqa: E501
        :rtype: list[Column]
        """
        return self._columns

    @columns.setter
    def columns(self, columns):
        """Sets the columns of this HubDbTableV3.

        List of columns in the table  # noqa: E501

        :param columns: The columns of this HubDbTableV3.  # noqa: E501
        :type columns: list[Column]
        """

        self._columns = columns

    @property
    def label(self):
        """Gets the label of this HubDbTableV3.  # noqa: E501

        Label of the table  # noqa: E501

        :return: The label of this HubDbTableV3.  # noqa: E501
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this HubDbTableV3.

        Label of the table  # noqa: E501

        :param label: The label of this HubDbTableV3.  # noqa: E501
        :type label: str
        """
        if self.local_vars_configuration.client_side_validation and label is None:  # noqa: E501
            raise ValueError("Invalid value for `label`, must not be `None`")  # noqa: E501

        self._label = label

    @property
    def published(self):
        """Gets the published of this HubDbTableV3.  # noqa: E501


        :return: The published of this HubDbTableV3.  # noqa: E501
        :rtype: bool
        """
        return self._published

    @published.setter
    def published(self, published):
        """Sets the published of this HubDbTableV3.


        :param published: The published of this HubDbTableV3.  # noqa: E501
        :type published: bool
        """

        self._published = published

    @property
    def column_count(self):
        """Gets the column_count of this HubDbTableV3.  # noqa: E501

        Number of columns including deleted  # noqa: E501

        :return: The column_count of this HubDbTableV3.  # noqa: E501
        :rtype: int
        """
        return self._column_count

    @column_count.setter
    def column_count(self, column_count):
        """Sets the column_count of this HubDbTableV3.

        Number of columns including deleted  # noqa: E501

        :param column_count: The column_count of this HubDbTableV3.  # noqa: E501
        :type column_count: int
        """

        self._column_count = column_count

    @property
    def allow_child_tables(self):
        """Gets the allow_child_tables of this HubDbTableV3.  # noqa: E501

        Specifies whether child tables can be created  # noqa: E501

        :return: The allow_child_tables of this HubDbTableV3.  # noqa: E501
        :rtype: bool
        """
        return self._allow_child_tables

    @allow_child_tables.setter
    def allow_child_tables(self, allow_child_tables):
        """Sets the allow_child_tables of this HubDbTableV3.

        Specifies whether child tables can be created  # noqa: E501

        :param allow_child_tables: The allow_child_tables of this HubDbTableV3.  # noqa: E501
        :type allow_child_tables: bool
        """

        self._allow_child_tables = allow_child_tables

    @property
    def created_at(self):
        """Gets the created_at of this HubDbTableV3.  # noqa: E501

        Timestamp at which the table is created  # noqa: E501

        :return: The created_at of this HubDbTableV3.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this HubDbTableV3.

        Timestamp at which the table is created  # noqa: E501

        :param created_at: The created_at of this HubDbTableV3.  # noqa: E501
        :type created_at: datetime
        """

        self._created_at = created_at

    @property
    def deleted(self):
        """Gets the deleted of this HubDbTableV3.  # noqa: E501


        :return: The deleted of this HubDbTableV3.  # noqa: E501
        :rtype: bool
        """
        return self._deleted

    @deleted.setter
    def deleted(self, deleted):
        """Sets the deleted of this HubDbTableV3.


        :param deleted: The deleted of this HubDbTableV3.  # noqa: E501
        :type deleted: bool
        """

        self._deleted = deleted

    @property
    def created_by(self):
        """Gets the created_by of this HubDbTableV3.  # noqa: E501


        :return: The created_by of this HubDbTableV3.  # noqa: E501
        :rtype: SimpleUser
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this HubDbTableV3.


        :param created_by: The created_by of this HubDbTableV3.  # noqa: E501
        :type created_by: SimpleUser
        """

        self._created_by = created_by

    @property
    def name(self):
        """Gets the name of this HubDbTableV3.  # noqa: E501

        Name of the table  # noqa: E501

        :return: The name of this HubDbTableV3.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this HubDbTableV3.

        Name of the table  # noqa: E501

        :param name: The name of this HubDbTableV3.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def enable_child_table_pages(self):
        """Gets the enable_child_table_pages of this HubDbTableV3.  # noqa: E501

        Specifies creation of multi-level dynamic pages using child tables  # noqa: E501

        :return: The enable_child_table_pages of this HubDbTableV3.  # noqa: E501
        :rtype: bool
        """
        return self._enable_child_table_pages

    @enable_child_table_pages.setter
    def enable_child_table_pages(self, enable_child_table_pages):
        """Sets the enable_child_table_pages of this HubDbTableV3.

        Specifies creation of multi-level dynamic pages using child tables  # noqa: E501

        :param enable_child_table_pages: The enable_child_table_pages of this HubDbTableV3.  # noqa: E501
        :type enable_child_table_pages: bool
        """

        self._enable_child_table_pages = enable_child_table_pages

    @property
    def id(self):
        """Gets the id of this HubDbTableV3.  # noqa: E501

        Id of the table  # noqa: E501

        :return: The id of this HubDbTableV3.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this HubDbTableV3.

        Id of the table  # noqa: E501

        :param id: The id of this HubDbTableV3.  # noqa: E501
        :type id: str
        """

        self._id = id

    @property
    def row_count(self):
        """Gets the row_count of this HubDbTableV3.  # noqa: E501

        Number of rows in the table  # noqa: E501

        :return: The row_count of this HubDbTableV3.  # noqa: E501
        :rtype: int
        """
        return self._row_count

    @row_count.setter
    def row_count(self, row_count):
        """Sets the row_count of this HubDbTableV3.

        Number of rows in the table  # noqa: E501

        :param row_count: The row_count of this HubDbTableV3.  # noqa: E501
        :type row_count: int
        """

        self._row_count = row_count

    @property
    def is_ordered_manually(self):
        """Gets the is_ordered_manually of this HubDbTableV3.  # noqa: E501


        :return: The is_ordered_manually of this HubDbTableV3.  # noqa: E501
        :rtype: bool
        """
        return self._is_ordered_manually

    @is_ordered_manually.setter
    def is_ordered_manually(self, is_ordered_manually):
        """Sets the is_ordered_manually of this HubDbTableV3.


        :param is_ordered_manually: The is_ordered_manually of this HubDbTableV3.  # noqa: E501
        :type is_ordered_manually: bool
        """

        self._is_ordered_manually = is_ordered_manually

    @property
    def updated_at(self):
        """Gets the updated_at of this HubDbTableV3.  # noqa: E501

        Timestamp at which the table is updated recently  # noqa: E501

        :return: The updated_at of this HubDbTableV3.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this HubDbTableV3.

        Timestamp at which the table is updated recently  # noqa: E501

        :param updated_at: The updated_at of this HubDbTableV3.  # noqa: E501
        :type updated_at: datetime
        """

        self._updated_at = updated_at

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HubDbTableV3):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, HubDbTableV3):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Lists

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.lists.configuration import Configuration


class PublicFormSubmissionOnPageFilter(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "form_id": "str",
        "coalescing_refine_by": "PublicFormSubmissionFilterCoalescingRefineBy",
        "pruning_refine_by": "PublicFormSubmissionFilterCoalescingRefineBy",
        "filter_type": "str",
        "page_id": "str",
        "operator": "str",
    }

    attribute_map = {
        "form_id": "formId",
        "coalescing_refine_by": "coalescingRefineBy",
        "pruning_refine_by": "pruningRefineBy",
        "filter_type": "filterType",
        "page_id": "pageId",
        "operator": "operator",
    }

    def __init__(
        self, form_id=None, coalescing_refine_by=None, pruning_refine_by=None, filter_type="FORM_SUBMISSION_ON_PAGE", page_id=None, operator=None, local_vars_configuration=None
    ):  # noqa: E501
        """PublicFormSubmissionOnPageFilter - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._form_id = None
        self._coalescing_refine_by = None
        self._pruning_refine_by = None
        self._filter_type = None
        self._page_id = None
        self._operator = None
        self.discriminator = None

        if form_id is not None:
            self.form_id = form_id
        if coalescing_refine_by is not None:
            self.coalescing_refine_by = coalescing_refine_by
        if pruning_refine_by is not None:
            self.pruning_refine_by = pruning_refine_by
        self.filter_type = filter_type
        self.page_id = page_id
        self.operator = operator

    @property
    def form_id(self):
        """Gets the form_id of this PublicFormSubmissionOnPageFilter.  # noqa: E501


        :return: The form_id of this PublicFormSubmissionOnPageFilter.  # noqa: E501
        :rtype: str
        """
        return self._form_id

    @form_id.setter
    def form_id(self, form_id):
        """Sets the form_id of this PublicFormSubmissionOnPageFilter.


        :param form_id: The form_id of this PublicFormSubmissionOnPageFilter.  # noqa: E501
        :type form_id: str
        """

        self._form_id = form_id

    @property
    def coalescing_refine_by(self):
        """Gets the coalescing_refine_by of this PublicFormSubmissionOnPageFilter.  # noqa: E501


        :return: The coalescing_refine_by of this PublicFormSubmissionOnPageFilter.  # noqa: E501
        :rtype: PublicFormSubmissionFilterCoalescingRefineBy
        """
        return self._coalescing_refine_by

    @coalescing_refine_by.setter
    def coalescing_refine_by(self, coalescing_refine_by):
        """Sets the coalescing_refine_by of this PublicFormSubmissionOnPageFilter.


        :param coalescing_refine_by: The coalescing_refine_by of this PublicFormSubmissionOnPageFilter.  # noqa: E501
        :type coalescing_refine_by: PublicFormSubmissionFilterCoalescingRefineBy
        """

        self._coalescing_refine_by = coalescing_refine_by

    @property
    def pruning_refine_by(self):
        """Gets the pruning_refine_by of this PublicFormSubmissionOnPageFilter.  # noqa: E501


        :return: The pruning_refine_by of this PublicFormSubmissionOnPageFilter.  # noqa: E501
        :rtype: PublicFormSubmissionFilterCoalescingRefineBy
        """
        return self._pruning_refine_by

    @pruning_refine_by.setter
    def pruning_refine_by(self, pruning_refine_by):
        """Sets the pruning_refine_by of this PublicFormSubmissionOnPageFilter.


        :param pruning_refine_by: The pruning_refine_by of this PublicFormSubmissionOnPageFilter.  # noqa: E501
        :type pruning_refine_by: PublicFormSubmissionFilterCoalescingRefineBy
        """

        self._pruning_refine_by = pruning_refine_by

    @property
    def filter_type(self):
        """Gets the filter_type of this PublicFormSubmissionOnPageFilter.  # noqa: E501


        :return: The filter_type of this PublicFormSubmissionOnPageFilter.  # noqa: E501
        :rtype: str
        """
        return self._filter_type

    @filter_type.setter
    def filter_type(self, filter_type):
        """Sets the filter_type of this PublicFormSubmissionOnPageFilter.


        :param filter_type: The filter_type of this PublicFormSubmissionOnPageFilter.  # noqa: E501
        :type filter_type: str
        """
        if self.local_vars_configuration.client_side_validation and filter_type is None:  # noqa: E501
            raise ValueError("Invalid value for `filter_type`, must not be `None`")  # noqa: E501
        allowed_values = ["FORM_SUBMISSION_ON_PAGE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and filter_type not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `filter_type` ({0}), must be one of {1}".format(filter_type, allowed_values))  # noqa: E501

        self._filter_type = filter_type

    @property
    def page_id(self):
        """Gets the page_id of this PublicFormSubmissionOnPageFilter.  # noqa: E501


        :return: The page_id of this PublicFormSubmissionOnPageFilter.  # noqa: E501
        :rtype: str
        """
        return self._page_id

    @page_id.setter
    def page_id(self, page_id):
        """Sets the page_id of this PublicFormSubmissionOnPageFilter.


        :param page_id: The page_id of this PublicFormSubmissionOnPageFilter.  # noqa: E501
        :type page_id: str
        """
        if self.local_vars_configuration.client_side_validation and page_id is None:  # noqa: E501
            raise ValueError("Invalid value for `page_id`, must not be `None`")  # noqa: E501

        self._page_id = page_id

    @property
    def operator(self):
        """Gets the operator of this PublicFormSubmissionOnPageFilter.  # noqa: E501


        :return: The operator of this PublicFormSubmissionOnPageFilter.  # noqa: E501
        :rtype: str
        """
        return self._operator

    @operator.setter
    def operator(self, operator):
        """Sets the operator of this PublicFormSubmissionOnPageFilter.


        :param operator: The operator of this PublicFormSubmissionOnPageFilter.  # noqa: E501
        :type operator: str
        """
        if self.local_vars_configuration.client_side_validation and operator is None:  # noqa: E501
            raise ValueError("Invalid value for `operator`, must not be `None`")  # noqa: E501
        allowed_values = ["FILLED_OUT", "NOT_FILLED_OUT"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and operator not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `operator` ({0}), must be one of {1}".format(operator, allowed_values))  # noqa: E501

        self._operator = operator

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicFormSubmissionOnPageFilter):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PublicFormSubmissionOnPageFilter):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    CRM Deal Splits

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from hubspot.crm.objects.deal_splits.api.batch_api import BatchApi

# import ApiClient
from hubspot.crm.objects.deal_splits.api_client import ApiClient
from hubspot.crm.objects.deal_splits.configuration import Configuration
from hubspot.crm.objects.deal_splits.exceptions import OpenApiException
from hubspot.crm.objects.deal_splits.exceptions import ApiTypeError
from hubspot.crm.objects.deal_splits.exceptions import ApiValueError
from hubspot.crm.objects.deal_splits.exceptions import ApiKeyError
from hubspot.crm.objects.deal_splits.exceptions import ApiAttributeError
from hubspot.crm.objects.deal_splits.exceptions import ApiException

# import models into sdk package
from hubspot.crm.objects.deal_splits.models.batch_input_public_object_id import BatchInputPublicObjectId
from hubspot.crm.objects.deal_splits.models.batch_response_deal_to_deal_splits import BatchResponseDealToDealSplits
from hubspot.crm.objects.deal_splits.models.batch_response_deal_to_deal_splits_with_errors import BatchResponseDealToDealSplitsWithErrors
from hubspot.crm.objects.deal_splits.models.deal_to_deal_splits import DealToDealSplits
from hubspot.crm.objects.deal_splits.models.error import Error
from hubspot.crm.objects.deal_splits.models.error_detail import ErrorDetail
from hubspot.crm.objects.deal_splits.models.public_deal_split_input import PublicDealSplitInput
from hubspot.crm.objects.deal_splits.models.public_deal_splits_batch_create_request import PublicDealSplitsBatchCreateRequest
from hubspot.crm.objects.deal_splits.models.public_deal_splits_create_request import PublicDealSplitsCreateRequest
from hubspot.crm.objects.deal_splits.models.public_object_id import PublicObjectId
from hubspot.crm.objects.deal_splits.models.simple_public_object import SimplePublicObject
from hubspot.crm.objects.deal_splits.models.standard_error import StandardError
from hubspot.crm.objects.deal_splits.models.value_with_timestamp import ValueWithTimestamp
